@@ -37,7 +37,7 @@
 class FilterLogView : public KDialogBase
 {
 
-Q_OBJECT
+TQ_OBJECT
 
   public:
 
