@@ -41,7 +41,7 @@ class TQMultiLineEdit;
  **/
 class KFeedbackDialog: public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
 
@@ -97,7 +97,7 @@ protected:
  **/
 class KFeedbackForm: public TQVBox
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     /**
@@ -186,7 +186,7 @@ protected:
  **/
 class KFeedbackQuestionList: public TQListView
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
 
